<?php

namespace Drupal\synhelper\Drush;

use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 */
class DrushContentImport extends DrushCommands {

  /**
   * Synhelper Content import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:content_import
   * @usage synhelper:scont $directory
   *   Full import from $directory.
   */
  public function import($directory) {
    $this->output()->writeln("Import Content from: $directory");
    \Drupal::service('synhelper.content_import')->import($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Blocks import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:block_import
   * @usage synhelper:scont $directory
   *   Blocks import from $directory/block.
   */
  public function importBlocks($directory) {
    $this->output()->writeln("Import Blocks from: $directory/block");
    \Drupal::service('synhelper.content_import')->importBlocks($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Taxonomy import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:taxonomy_import
   * @usage synhelper:scont $directory
   *   Taxonomy import from $directory/taxonomy.
   */
  public function importTaxonomy($directory) {
    $this->output()->writeln("Import Taxonomy from: $directory/taxonomy");
    \Drupal::service('synhelper.content_import')->importTaxonomy($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Products import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:product_import
   * @usage synhelper:scont $directory
   *   Products import from $directory/products.
   */
  public function importProducts($directory) {
    $this->output()->writeln("Import Products from: $directory/products");
    \Drupal::service('synhelper.content_import')->importProducts($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Menu import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:menu_import
   * @usage synhelper:scont $directory
   *   Menu import from $directory/menu.
   */
  public function importMenu($directory) {
    $this->output()->writeln("Import Menu from: $directory/menu");
    \Drupal::service('synhelper.content_import')->importMenu($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Contacts import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:contacts_import
   * @usage synhelper:scont $directory
   *   Contacts import from $directory/contacts.
   */
  public function importContacts($directory) {
    $this->output()->writeln("Import Contacts from: $directory/contacts");
    \Drupal::service('synhelper.content_import')->importContacts($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Nodes import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:node_import
   * @usage synhelper:scont $directory
   *   Nodes import from $directory/nodes.
   */
  public function importNode($directory) {
    $this->output()->writeln("Import Nodes from: $directory/nodes");
    \Drupal::service('synhelper.content_import')->importNode($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synhelper Synlanding Config import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synhelper:synlanding_config_import
   * @usage synhelper:scont $directory
   *   Synlanding Config import from $directory/synlanding.
   */
  public function setSynLandingConfig($directory) {
    $this->output()->writeln("Import SynLandingConfig from: $directory/synlanding");
    \Drupal::service('synhelper.content_import')->setSynLandingConfig($directory);
    $this->output()->writeln("!NOTE Done.");
  }

}
